==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPaneDragStartEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPaneDragStartEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneDragStartEventArgsDetailDescription, _super);
    function WebPaneDragStartEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.f = null;
        return _this;
    }
    WebPaneDragStartEventArgsDetailDescription.prototype.get_type = function () {
        return "WebPaneDragStartEventArgsDetail";
    };
    Object.defineProperty(WebPaneDragStartEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneDragStartEventArgsDetailDescription.prototype, "sourcePane", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("SourcePane");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneDragStartEventArgsDetailDescription.prototype, "panes", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Panes");
        },
        enumerable: true,
        configurable: true
    });
    WebPaneDragStartEventArgsDetailDescription.$t = markType(WebPaneDragStartEventArgsDetailDescription, 'WebPaneDragStartEventArgsDetailDescription', Description.$);
    WebPaneDragStartEventArgsDetailDescription.__marshalByValue = true;
    WebPaneDragStartEventArgsDetailDescription.__marshalByValueAlias = "PaneDragStartEventArgsDetail";
    return WebPaneDragStartEventArgsDetailDescription;
}(Description));
export { WebPaneDragStartEventArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebPaneDragStartEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPaneDragStartEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragStartEventArgsDetailDescription, _super);
    function WebPaneDragStartEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.h = null;
        return _this;
    }
    WebPaneDragStartEventArgsDetailDescription.prototype.get_type = function () {
        return "WebPaneDragStartEventArgsDetail";
    };
    Object.defineProperty(WebPaneDragStartEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPaneDragStartEventArgsDetailDescription.prototype, "sourcePane", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("SourcePane");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPaneDragStartEventArgsDetailDescription.prototype, "panes", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Panes");
        },
        enumerable: false,
        configurable: true
    });
    WebPaneDragStartEventArgsDetailDescription.$t = markType(WebPaneDragStartEventArgsDetailDescription, 'WebPaneDragStartEventArgsDetailDescription', Description.$);
    WebPaneDragStartEventArgsDetailDescription.__marshalByValue = true;
    WebPaneDragStartEventArgsDetailDescription.__marshalByValueAlias = "PaneDragStartEventArgsDetail";
    return WebPaneDragStartEventArgsDetailDescription;
}(Description));
export { WebPaneDragStartEventArgsDetailDescription };
